pub struct GeneratedRange {
pub start: Position,
pub end: Position,
pub is_stack_frame: bool,
pub is_hidden: bool,
pub definition: Option<usize>,
pub call_site: Option<CallSite>,
pub bindings: Vec<Binding>,
pub children: Vec<GeneratedRange>,
}Expand description
A generated range in the output code.
Fields
start: Positionend: Positionis_stack_frame: boolWhether this range is a stack frame (function boundary).
Whether this stack frame should be hidden from traces.
definition: Option<usize>Index into the pre-order list of all original scope starts.
call_site: Option<CallSite>Call site if this range represents an inlined function body.
bindings: Vec<Binding>Variable bindings (one per variable in the referenced original scope).
children: Vec<GeneratedRange>Child ranges nested within this one.